==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/Util__245.c <==
// final class org.dellroad.jc.cgen.Util$5

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator
// @dep_class b078cecdd81bb390 org_dellroad_jc_cgen_Util
// @dep_class 60ef816b1e455b7f org_dellroad_jc_cgen_Util__245
// @dep_class 634bd13ff2d8ac70 soot_SootClass

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Comparator
// @dep_header org_dellroad_jc_cgen_Util
// @dep_header org_dellroad_jc_cgen_Util__245
// @dep_header soot_SootClass

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Comparator.h"
#include "org/dellroad/jc/cgen/Util.h"
#include "org/dellroad/jc/cgen/Util__245.h"
#include "soot/SootClass.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_org_dellroad_jc_cgen_Util__245$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_dellroad_jc_cgen_Util__245$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_dellroad_jc_cgen_Util__245$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_dellroad_jc_cgen_Util__245$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_Util__245$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_org_dellroad_jc_cgen_Util__245$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_dellroad_jc_cgen_Util__245$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_Util__245, _init$52f4ad9f2989aeee);

void
_jc_org_dellroad_jc_cgen_Util__245$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_dellroad_jc_cgen_Util__245$object *this)
{
	struct _jc_org_dellroad_jc_cgen_Util__245$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(196);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_org_dellroad_jc_cgen_Util__245$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_org_dellroad_jc_cgen_Util__245$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_org_dellroad_jc_cgen_Util__245$type,
	.param_types=		&_jc_org_dellroad_jc_cgen_Util__245$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_Util__245$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_org_dellroad_jc_cgen_Util__245$vtable, org_dellroad_jc_cgen_Util__245.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_org_dellroad_jc_cgen_Util__245$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_Util__245, compare$ef65339aa5f9531b);

jint
_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_org_dellroad_jc_cgen_Util__245$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	jint i0;
	struct _jc_org_dellroad_jc_cgen_Util__245$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_soot_SootClass$object *r3;
	struct _jc_soot_SootClass$object *r4;
	struct _jc_object *r5;
	struct _jc_java_lang_String$object *r6;
	struct _jc_java_lang_String$object *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(198);				// 0
	r3 = _JC_CAST(env, &_jc_soot_SootClass$type, r1);
	_JC_LINE_NUMBER(199);				// 1
	r4 = _JC_CAST(env, &_jc_soot_SootClass$type, r2);
	_JC_LINE_NUMBER(200);				// 2
	r5 = _JC_STATIC_FIELD(env, org_dellroad_jc_cgen_Util, utf8Comparator, 0);
	r6 = _JC_INVOKE_VIRTUAL(env, soot_SootClass, getName$bec186f2ce7e1882, r3);
	r7 = _JC_INVOKE_VIRTUAL(env, soot_SootClass, getName$bec186f2ce7e1882, r4);
	i0 = _JC_INVOKE_INTERFACE(env, r5, _JC_JLONG(0xef65339aa5f9531b), jint, r6, r7);
	return i0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_dellroad_jc_cgen_Util__245$methods[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$interfaces[] = {
	&_jc_java_util_Comparator$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_27[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_1,
	[27]=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_org_dellroad_jc_cgen_Util__245$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_127[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[113]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_113,
	[125]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_125,
	[127]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_127
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_dellroad_jc_cgen_Util__245$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
	{ "org/dellroad/jc/cgen/Util",	_JC_JLONG(0xb078cecdd81bb390) },
	{ "soot/SootClass",	_JC_JLONG(0x634bd13ff2d8ac70) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_dellroad_jc_cgen_Util__245$vtype _jc_org_dellroad_jc_cgen_Util__245$type = {
    .type= {
	.name=			"org/dellroad/jc/cgen/Util$5",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_dellroad_jc_cgen_Util__245$interfaces) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$interfaces),
	.interfaces=		_jc_org_dellroad_jc_cgen_Util__245$interfaces,
	.imethod_hash_table=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_table,
	.imethod_quick_table=	_jc_org_dellroad_jc_cgen_Util__245$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x60ef816b1e455b7f),
		.source_file=		"Util.java",
		.instance_size=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$refs) + sizeof(_jc_org_dellroad_jc_cgen_Util__245$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$methods) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$methods),
		.methods=		_jc_org_dellroad_jc_cgen_Util__245$methods,
		.instanceof_hash_table=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$class_depends) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$class_depends),
		.class_depends=		_jc_org_dellroad_jc_cgen_Util__245$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_dellroad_jc_cgen_Util__245= {
	    .compare$ef65339aa5f9531b=
		&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b,
	},
    }
};

==> jc-1.4.5.tar.gz: org/dellroad/jc/cgen/Util__245.c <==
// final class org.dellroad.jc.cgen.Util$5

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 1ad5438e0f3ab7fd java_util_Comparator
// @dep_class b078cecdd81bb390 org_dellroad_jc_cgen_Util
// @dep_class 60ef816b1e455b7f org_dellroad_jc_cgen_Util__245
// @dep_class 634bd13ff2d8ac70 soot_SootClass

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Comparator
// @dep_header org_dellroad_jc_cgen_Util
// @dep_header org_dellroad_jc_cgen_Util__245
// @dep_header soot_SootClass

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Comparator.h"
#include "org/dellroad/jc/cgen/Util.h"
#include "org/dellroad/jc/cgen/Util__245.h"
#include "soot/SootClass.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_org_dellroad_jc_cgen_Util__245$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_org_dellroad_jc_cgen_Util__245$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_org_dellroad_jc_cgen_Util__245$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_org_dellroad_jc_cgen_Util__245$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_Util__245$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_org_dellroad_jc_cgen_Util__245$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_org_dellroad_jc_cgen_Util__245$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_Util__245, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_org_dellroad_jc_cgen_Util__245$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_org_dellroad_jc_cgen_Util__245$object *this)
{
	struct _jc_org_dellroad_jc_cgen_Util__245$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(196);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final int compare(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_org_dellroad_jc_cgen_Util__245$linenum_table$compare$ef65339aa5f9531b[];

static const unsigned char _jc_org_dellroad_jc_cgen_Util__245$param_ptypes$compare$ef65339aa5f9531b[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_INT };

static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$param_types$compare$ef65339aa5f9531b[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b = {
	.name=			"compare",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)I",
	.class=			&_jc_org_dellroad_jc_cgen_Util__245$type,
	.param_types=		&_jc_org_dellroad_jc_cgen_Util__245$param_types$compare$ef65339aa5f9531b,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_org_dellroad_jc_cgen_Util__245$param_ptypes$compare$ef65339aa5f9531b,
	.signature_hash=	_JC_JLONG(0xef65339aa5f9531b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_org_dellroad_jc_cgen_Util__245$vtable, org_dellroad_jc_cgen_Util__245.compare$ef65339aa5f9531b) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_org_dellroad_jc_cgen_Util__245$linenum_table$compare$ef65339aa5f9531b
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(org_dellroad_jc_cgen_Util__245, compare$ef65339aa5f9531b);

jint _JC_JCNI_ATTR
_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b(_jc_env *const env, _jc_org_dellroad_jc_cgen_Util__245$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	jint i0;
	struct _jc_org_dellroad_jc_cgen_Util__245$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_soot_SootClass$object *r3;
	struct _jc_soot_SootClass$object *r4;
	struct _jc_object *r5;
	struct _jc_java_lang_String$object *r6;
	struct _jc_java_lang_String$object *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(198);				// 0
	r3 = _JC_CAST(env, &_jc_soot_SootClass$type, r1);
	_JC_LINE_NUMBER(199);				// 1
	r4 = _JC_CAST(env, &_jc_soot_SootClass$type, r2);
	_JC_LINE_NUMBER(200);				// 2
	r5 = _JC_STATIC_FIELD(env, org_dellroad_jc_cgen_Util, utf8Comparator, 0);
	r6 = _JC_INVOKE_VIRTUAL(env, soot_SootClass, getName$bec186f2ce7e1882, r3);
	r7 = _JC_INVOKE_VIRTUAL(env, soot_SootClass, getName$bec186f2ce7e1882, r4);
	i0 = _JC_INVOKE_INTERFACE(env, r5, _JC_JLONG(0xef65339aa5f9531b), jint, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *), r6, r7);
	return i0;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_org_dellroad_jc_cgen_Util__245$methods[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$_init$52f4ad9f2989aeee,
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$interfaces[] = {
	&_jc_java_util_Comparator$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_1[] = {
	&_jc_java_lang_Object$method_info$equals$8a15e0625571c581,
	_JC_NULL
};
static _jc_method *_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_27[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$method_info$compare$ef65339aa5f9531b,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_1,
	[27]=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_bucket_27
};

// Interface "quick" lookup hash table
static const void *_jc_org_dellroad_jc_cgen_Util__245$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[1]=	&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	[27]=	&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_125[] = {
	&_jc_java_util_Comparator$type,
	_JC_NULL
};
static _jc_type *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_127[] = {
	&_jc_org_dellroad_jc_cgen_Util__245$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_101,
	[125]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_125,
	[127]=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_bucket_127
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_org_dellroad_jc_cgen_Util__245$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Comparator",	_JC_JLONG(0x1ad5438e0f3ab7fd) },
	{ "org/dellroad/jc/cgen/Util",	_JC_JLONG(0xb078cecdd81bb390) },
	{ "soot/SootClass",	_JC_JLONG(0x634bd13ff2d8ac70) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_org_dellroad_jc_cgen_Util__245$vtype _jc_org_dellroad_jc_cgen_Util__245$type = {
    .type= {
	.name=			"org/dellroad/jc/cgen/Util$5",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_org_dellroad_jc_cgen_Util__245$interfaces) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$interfaces),
	.interfaces=		_jc_org_dellroad_jc_cgen_Util__245$interfaces,
	.imethod_hash_table=	_jc_org_dellroad_jc_cgen_Util__245$imethod_hash_table,
	.imethod_quick_table=	_jc_org_dellroad_jc_cgen_Util__245$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x60ef816b1e455b7f),
		.source_file=		"Util.java",
		.instance_size=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$refs) + sizeof(_jc_org_dellroad_jc_cgen_Util__245$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$methods) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$methods),
		.methods=		_jc_org_dellroad_jc_cgen_Util__245$methods,
		.instanceof_hash_table=	_jc_org_dellroad_jc_cgen_Util__245$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_org_dellroad_jc_cgen_Util__245$class_depends) / sizeof(*_jc_org_dellroad_jc_cgen_Util__245$class_depends),
		.class_depends=		_jc_org_dellroad_jc_cgen_Util__245$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.org_dellroad_jc_cgen_Util__245= {
	    .compare$ef65339aa5f9531b=
		&_jc_org_dellroad_jc_cgen_Util__245$method$compare$ef65339aa5f9531b,
	},
    }
};
